==> webull-openapi-java-sdk-1.0.2-sources.jar: com/webull/openapi/data/common/ArgNames.java <==
/*
 * Copyright 2022 Webull
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.webull.openapi.data.common;

public final class ArgNames {

    private ArgNames() {
    }

    public static final String SESSION_ID = "session_id";
    public static final String SYMBOLS = "symbols";
    public static final String SYMBOL = "symbol";
    public static final String CATEGORY = "category";
    public static final String TIMESPAN = "timespan";
    public static final String COUNT = "count";
    public static final String REAL_TIME_REQUIRED = "real_time_required";
    public static final String TRADING_SESSIONS = "trading_sessions";
    public static final String DEPTH = "depth";
    public static final String EXTEND_HOUR_REQUIRED = "extend_hour_required";
    public static final String OVERNIGHT_REQUIRED = "overnight_required";
    public static final String SUBTYPES = "sub_types";
    public static final String UNSUBSCRIBE_ALL = "unsubscribe_all";
    public static final String INSTRUMENT_IDS = "instrument_ids";
    public static final String LAST_INSTRUMENT_ID = "last_instrument_id";
    public static final String DATE = "date";
    public static final String START_DATE = "start_date";
    public static final String END_DATE = "end_date";
    public static final String EVENT_TYPES = "event_types";
    public static final String LAST_UPDATE_TIME = "last_update_time";
    public static final String PAGE_NUMBER = "page_number";
    public static final String PAGE_SIZE = "page_size";
}

==> webull-openapi-java-sdk-1.0.8-sources.jar: com/webull/openapi/data/common/ArgNames.java <==
/*
 * Copyright 2022 Webull
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.webull.openapi.data.common;

public final class ArgNames {

    private ArgNames() {
    }

    public static final String SESSION_ID = "session_id";
    public static final String SYMBOLS = "symbols";
    public static final String SYMBOL = "symbol";
    public static final String CATEGORY = "category";
    public static final String TIMESPAN = "timespan";
    public static final String COUNT = "count";
    public static final String REAL_TIME_REQUIRED = "real_time_required";
    public static final String TRADING_SESSIONS = "trading_sessions";
    public static final String DEPTH = "depth";
    public static final String EXTEND_HOUR_REQUIRED = "extend_hour_required";
    public static final String OVERNIGHT_REQUIRED = "overnight_required";
    public static final String SUBTYPES = "sub_types";
    public static final String UNSUBSCRIBE_ALL = "unsubscribe_all";
    public static final String INSTRUMENT_IDS = "instrument_ids";
    public static final String LAST_INSTRUMENT_ID = "last_instrument_id";
    public static final String DATE = "date";
    public static final String START_DATE = "start_date";
    public static final String END_DATE = "end_date";
    public static final String EVENT_TYPES = "event_types";
    public static final String LAST_UPDATE_TIME = "last_update_time";
    public static final String PAGE_NUMBER = "page_number";
    public static final String PAGE_NO = "page_no";
    public static final String PAGE_SIZE = "page_size";
    public static final String CODE = "code";
    public static final String TYPE = "contract_type";
    public static final String NEXT_CURSOR = "next_cursor";
    public static final String STATUS = "status";
    public static final String PARAMETER = "parameter";
}
